/*
** dtools.h - utility functions used by voiceover server code
** Copyright (C) 2019, 2020  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

int Daemonize(int);		/* become a daemon */
/*
** Daemonize() will convert the process into a daemon
** by forking() off and orphaning a child process
** (so that it becomes a process that's not a process group leader)
** The orphan child process then uses setsid() to become
** a session leader in a new session, and the process group
** leader of a new process group within that session.
** It will not have a controlling terminal (courtesy of setsid()).
** Daemonize() will then close all FDs except for stdin, stdout,
** and stderr. If save_stdio is zero, Daemonize will redirect
** stdin, stdout and stderr to /dev/null, otherwise it will leave
** them unchanged.
**
** Failures, if any, will log to syslog
*/
/* values for argument to Daemonize() */
#define DAEMONIZE_NULL_STDIO	0
#define DAEMONIZE_SAVE_STDIO	1
/* return values from Daemonize() */
#define	DAEMONIZED_OK	1
#define	DAEMONIZED_ERR	0

extern int ChangeUser(char *);	/* change uid/gid to uid/gid of this user */
/*
** ChangeUser will cause the process to assume the euid and egid
** of the named user. If NULL presented as the name, then ChangeUser
** will attempt to reset euid to ruid and egid to rgid.
**
** Failures, if any, will log to syslog
*/
/* return values from ChangeUser() */
#define	CHANGEUSER_OK	1
#define CHANGEUSER_ERR	0


extern int PidFile(char *);	/* record pid in file - for external signalling */
/*
** PidFile writes the PID of the current process out to the named file
**
** Failures, if any, will log to syslog
*/
