/*
** voxcheckconfig - Configuration file validator for voxd VoiceOver daemon
** Copyright (C) 2017, 2020  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

#include "voxconfig.h"
#include "voxd.h"

int main(int argc, char *argv[])
{
  int rc = EXIT_FAILURE;
  int	opt;
  extern char *optarg;
  char	*ConfigPath = NULL;
  int	Rewrite = 0;
  int	argerrors = 0;

  while ((opt = getopt(argc,argv,"c:r")) != -1)
  {
    switch (opt)
    {
      case 'c':	/* change config path */
	free(ConfigPath);
	ConfigPath = strdup(optarg);
	break;

      case 'r':	/* set rewrite flag */
	Rewrite = 1;
	break;

      default:	/* anything else */
	argerrors = 1;
	break;
    }
  }
  if (ConfigPath == NULL) ConfigPath = strdup(CONFIGPATH);

  if (argerrors == 0 && argc - optind == 0)
  {
    struct show *Show;

    if ((Show = OpenShow(ConfigPath)))
    {
      if (Rewrite)
      {
        fprintf(stdout,"# voxd config file %s\n\n",ConfigPath);
	WriteShow(stdout,Show);
      }
      else
	printf("%s looks clean to me\n",ConfigPath);
      rc = EXIT_SUCCESS;
    }
    else printf("The voiceover config file (at %s) has errors\n",ConfigPath);
  }
  else fprintf(stderr,"Usage: %s [-c configpath] [-r]\n",argv[0]);

  return rc;
} 
